@@ -222,8 +222,7 @@ impl Cursor<'_> {
             '"' if allows_double => {
                 self.bump();
                 let terminated = self.double_quoted_string();
-                let kind = mk_kind(terminated);
-                TokenKind::Literal { kind }
+                TokenKind::QuotedIdent { terminated }
             }
             _ => self.ident_or_unknown_prefix(),
         }
@@ -280,7 +279,7 @@ impl Cursor<'_> {
                     return LiteralKind::Int {
                         base,
                         empty_int: false,
-                    }
+                    };
                 }
             }
         } else {
@@ -303,6 +302,14 @@ impl Cursor<'_> {
                         }
                         _ => (),
                     }
+                } else {
+                    match self.first() {
+                        'e' | 'E' => {
+                            self.bump();
+                            empty_exponent = !self.eat_float_exponent();
+                        }
+                        _ => (),
+                    }
                 }
                 LiteralKind::Float {
                     base,
@@ -358,13 +365,13 @@ impl Cursor<'_> {
     fn double_quoted_string(&mut self) -> bool {
         while let Some(c) = self.bump() {
             match c {
-                '"' => {
-                    return true;
-                }
-                '\\' if self.first() == '\\' || self.first() == '"' => {
+                '"' if self.first() == '"' => {
                     // Bump again to skip escaped character.
                     self.bump();
                 }
+                '"' => {
+                    return true;
+                }
                 _ => (),
             }
         }
@@ -389,6 +396,7 @@ impl Cursor<'_> {
             }
         }
 
+        // we have a dollar quoted string deliminated with `$$`
         if start.is_empty() {
             loop {
                 self.eat_while(|c| c != '$');
@@ -428,9 +436,9 @@ impl Cursor<'_> {
                 }
 
                 // closing '$'
-                if self.first() == '$' {
+                let terminated = match_count == start.len();
+                if self.first() == '$' && terminated {
                     self.bump();
-                    let terminated = match_count == start.len();
                     return TokenKind::Literal {
                         kind: LiteralKind::DollarQuotedString { terminated },
                     };
@@ -586,6 +594,14 @@ $foo$hello$world$bar$
 "#))
     }
 
+    #[test]
+    fn dollar_strings_part2() {
+        assert_debug_snapshot!(lex(r#"
+DO $doblock$
+end
+$doblock$;"#))
+    }
+
     #[test]
     fn dollar_quote_mismatch_tags_simple() {
         assert_debug_snapshot!(lex(r#"
@@ -615,6 +631,7 @@ $foo$hello$world$bar$
 1e-10
 1e+10
 1e10
+4664.E+5
 "#))
     }
 
@@ -729,6 +746,13 @@ U&"d!0061t!+000061" UESCAPE '!'
 
 
 "hello-world
+"#))
+    }
+
+    #[test]
+    fn quoted_ident_with_escape_quote() {
+        assert_debug_snapshot!(lex(r#"
+"foo "" bar"
 "#))
     }
 }
