@@ -1,4 +1,4 @@
-use squawk_syntax::{ast, Parse, SourceFile};
+use squawk_syntax::{Parse, SourceFile, ast};
 
 use crate::{Linter, Rule, Violation};
 
