@@ -25,9 +25,24 @@ select 1 in c;
 -- type cast must use a string literal
 select numeric 1234;
 
+-- missing comma
+select array[1 2,3];
+-- extra comma
+select array[1, ,3];
+-- trailing comma
+select array[1,2,3,];
+
+-- cast with malformed type mod args
+select cast(x as varchar(100 200));
+select cast(x as varchar(100, , 200));
+select cast(x as t(a, b,));
+
 -- regression test: this would cause the parser to get stuck & panic, now it
 -- warns about a missing semicolon
 select select;
 
+-- extra comma
+select a, from t;
+
 -- trailing comma at EOF
 select 1,
